import           Hkl.Projects

{-# ANN module "HLint: ignore Use camelCase" #-}

main :: IO ()
-- main = main_calibration
-- main = main_diffabs
main = mainSixs
